@@ -3,6 +3,7 @@ set -euo pipefail
 
 export ARTIFACT_NAME="yazi-$1"
 export YAZI_GEN_COMPLETIONS=1
+export MACOSX_DEPLOYMENT_TARGET="10.11"
 
 # Setup Rust toolchain
 if [[ "$1" == *-musl ]]; then
@@ -12,8 +13,7 @@ else
 fi
 
 # Build for the target
-cargo build -p yazi-cli --release --locked --target "$1"
-cargo build -p yazi-fm --release --locked --target "$1"
+cargo build --release --locked --target "$1"
 
 # Create the artifact
 mkdir -p "$ARTIFACT_NAME/completions"
