@@ -5,10 +5,13 @@ use std::{env, error::Error};
 
 use clap::CommandFactory;
 use clap_complete::{generate_to, Shell};
-use vergen::EmitBuilder;
+use vergen_gitcl::{BuildBuilder, Emitter, GitclBuilder};
 
 fn main() -> Result<(), Box<dyn Error>> {
-	EmitBuilder::builder().build_date().git_sha(true).emit()?;
+	Emitter::default()
+		.add_instructions(&BuildBuilder::default().build_date(true).build()?)?
+		.add_instructions(&GitclBuilder::default().commit_date(true).sha(true).build()?)?
+		.emit()?;
 
 	if env::var_os("YAZI_GEN_COMPLETIONS").is_none() {
 		return Ok(());
