@@ -35,6 +35,7 @@ pub static PREVIEW: RoCell<preview::Preview> = RoCell::new();
 pub static TASKS: RoCell<tasks::Tasks> = RoCell::new();
 pub static THEME: RoCell<theme::Theme> = RoCell::new();
 pub static INPUT: RoCell<popup::Input> = RoCell::new();
+pub static CONFIRM: RoCell<popup::Confirm> = RoCell::new();
 pub static SELECT: RoCell<popup::Select> = RoCell::new();
 pub static WHICH: RoCell<which::Which> = RoCell::new();
 
@@ -55,6 +56,7 @@ pub fn init() -> anyhow::Result<()> {
 	TASKS.init(<_>::from_str(yazi_toml)?);
 	THEME.init(<_>::from_str(theme_toml)?);
 	INPUT.init(<_>::from_str(yazi_toml)?);
+	CONFIRM.init(<_>::from_str(yazi_toml)?);
 	SELECT.init(<_>::from_str(yazi_toml)?);
 	WHICH.init(<_>::from_str(yazi_toml)?);
 
