@@ -1,7 +1,9 @@
 mod manager;
+mod mouse;
 mod ratio;
 mod sorting;
 
 pub use manager::*;
+pub use mouse::*;
 pub use ratio::*;
 pub use sorting::*;
