@@ -1,4 +1,4 @@
-use std::str::FromStr;
+use std::{fmt::Display, str::FromStr};
 
 use anyhow::bail;
 use serde::{Deserialize, Serialize};
@@ -14,6 +14,7 @@ pub enum SortBy {
 	Alphabetical,
 	Natural,
 	Size,
+	Random,
 }
 
 impl FromStr for SortBy {
@@ -28,6 +29,7 @@ impl FromStr for SortBy {
 			"alphabetical" => Self::Alphabetical,
 			"natural" => Self::Natural,
 			"size" => Self::Size,
+			"random" => Self::Random,
 			_ => bail!("invalid sort_by value: {s}"),
 		})
 	}
@@ -39,9 +41,9 @@ impl TryFrom<String> for SortBy {
 	fn try_from(s: String) -> Result<Self, Self::Error> { Self::from_str(&s) }
 }
 
-impl ToString for SortBy {
-	fn to_string(&self) -> String {
-		match self {
+impl Display for SortBy {
+	fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+		f.write_str(match self {
 			Self::None => "none",
 			Self::Modified => "modified",
 			Self::Created => "created",
@@ -49,7 +51,7 @@ impl ToString for SortBy {
 			Self::Alphabetical => "alphabetical",
 			Self::Natural => "natural",
 			Self::Size => "size",
-		}
-		.to_string()
+			Self::Random => "random",
+		})
 	}
 }
