@@ -21,9 +21,9 @@ pub struct Preloader {
 
 impl Preloader {
 	#[inline]
-	pub fn matches(&self, path: &Path, mime: Option<&str>) -> bool {
-		self.mime.as_ref().zip(mime).map_or(false, |(p, m)| p.match_mime(m))
-			|| self.name.as_ref().is_some_and(|p| p.match_path(path, mime == Some(MIME_DIR)))
+	pub fn matches(&self, path: &Path, mime: &str) -> bool {
+		self.mime.as_ref().is_some_and(|p| p.match_mime(mime))
+			|| self.name.as_ref().is_some_and(|p| p.match_path(path, mime == MIME_DIR))
 	}
 }
 
