@@ -1,6 +1,7 @@
 mod bulk_rename;
 mod close;
 mod create;
+mod hardlink;
 mod hover;
 mod link;
 mod open;
@@ -20,5 +21,6 @@ mod unyank;
 mod update_files;
 mod update_mimetype;
 mod update_paged;
+mod update_task;
 mod update_yanked;
 mod yank;
