@@ -1,28 +1,23 @@
-use anyhow::Result;
 use tokio::sync::oneshot;
 use yazi_config::popup::SelectCfg;
-use yazi_shared::{emit, event::Cmd, render, term::Term, Layer};
+use yazi_shared::{event::Cmd, render};
 
 use crate::select::Select;
 
 pub struct Opt {
 	cfg: SelectCfg,
-	tx:  oneshot::Sender<Result<usize>>,
+	tx:  oneshot::Sender<anyhow::Result<usize>>,
 }
 
 impl TryFrom<Cmd> for Opt {
 	type Error = ();
 
-	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> { c.take_data().ok_or(()) }
+	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
+		Ok(Self { cfg: c.take_any("cfg").ok_or(())?, tx: c.take_any("tx").ok_or(())? })
+	}
 }
 
 impl Select {
-	pub async fn _show(cfg: SelectCfg) -> Result<usize> {
-		let (tx, rx) = oneshot::channel();
-		emit!(Call(Cmd::new("show").with_data(Opt { cfg, tx }), Layer::Select));
-		rx.await.unwrap_or_else(|_| Term::goodbye(|| false))
-	}
-
 	pub fn show(&mut self, opt: impl TryInto<Opt>) {
 		let Ok(opt) = opt.try_into() else {
 			return;
