@@ -1,6 +1,6 @@
 use tokio::sync::mpsc;
 use tracing::error;
-use yazi_shared::event::Cmd;
+use yazi_shared::event::{Cmd, Data};
 
 use crate::which::Which;
 
@@ -14,8 +14,8 @@ impl TryFrom<Cmd> for Opt {
 
 	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
 		Ok(Self {
-			tx:  c.take_data().ok_or(())?,
-			idx: c.take_first().and_then(|s| s.parse().ok()).ok_or(())?,
+			tx:  c.take_any("tx").ok_or(())?,
+			idx: c.first().and_then(Data::as_usize).ok_or(())?,
 		})
 	}
 }
@@ -27,7 +27,7 @@ impl Which {
 		};
 
 		if opt.tx.try_send(opt.idx).is_err() {
-			error!("callback: send error");
+			error!("which callback: send error");
 		}
 	}
 }
