@@ -12,18 +12,16 @@ impl Progress {
 	) -> Vec<Vec<(u16, u16, ratatui::buffer::Cell)>> {
 		let mut patches = vec![];
 		let mut f = || {
-			let comp: Table = LUA.globals().get("Progress")?;
+			let comp: Table = LUA.globals().raw_get("Progress")?;
 			for widget in comp.call_method::<_, Vec<AnyUserData>>("partial_render", ())? {
-				let Some(w) = cast_to_renderable(widget) else {
-					continue;
-				};
+				let Some(w) = cast_to_renderable(&widget) else { continue };
 
 				let area = w.area();
 				w.render(buf);
 
 				let mut patch = Vec::with_capacity(area.width as usize * area.height as usize);
-				for x in area.left()..area.right() {
-					for y in area.top()..area.bottom() {
+				for y in area.top()..area.bottom() {
+					for x in area.left()..area.right() {
 						patch.push((x, y, mem::take(buf.get_mut(x, y))));
 					}
 				}
@@ -36,7 +34,7 @@ impl Progress {
 		};
 
 		if let Err(e) = f() {
-			error!("{:?}", e);
+			error!("{e}");
 		}
 		patches
 	}
