@@ -3,7 +3,7 @@ use ratatui::{buffer::Buffer, layout::Rect, widgets::Widget};
 use tracing::error;
 use yazi_plugin::{bindings::Cast, elements::render_widgets, LUA};
 
-use super::{completion, input, select, tasks, which};
+use super::{completion, confirm, input, select, tasks, which};
 use crate::{components, help, Ctx};
 
 pub(super) struct Root<'a> {
@@ -41,6 +41,10 @@ impl<'a> Widget for Root<'a> {
 			input::Input::new(self.cx).render(area, buf);
 		}
 
+		if self.cx.confirm.visible {
+			confirm::Confirm::new(self.cx).render(area, buf);
+		}
+
 		if self.cx.help.visible {
 			help::Layout::new(self.cx).render(area, buf);
 		}
