@@ -3,15 +3,14 @@ local TEXT = "ABCDEFGHIJKLM\nNOPQRSTUVWXYZ\nabcdefghijklm\nnopqrstuvwxyz\n123456
 local M = {}
 
 function M:peek()
-	local cache = ya.file_cache(self)
-	if not cache then
+	local start, cache = os.clock(), ya.file_cache(self)
+	if not cache or self:preload() ~= 1 then
 		return
 	end
 
-	if self:preload() == 1 then
-		ya.image_show(cache, self.area)
-		ya.preview_widgets(self, {})
-	end
+	ya.sleep(math.max(0, PREVIEW.image_delay / 1000 + start - os.clock()))
+	ya.image_show(cache, self.area)
+	ya.preview_widgets(self, {})
 end
 
 function M:seek() end
