@@ -1,20 +1,18 @@
 #![allow(clippy::module_inception)]
 
 mod bindings;
-mod cha;
-mod file;
 mod icon;
 mod input;
+mod mouse;
 mod permit;
 mod position;
 mod range;
 mod window;
 
 pub use bindings::*;
-pub use cha::*;
-pub use file::*;
 pub use icon::*;
 pub use input::*;
+pub use mouse::*;
 pub use permit::*;
 pub use position::*;
 pub use range::*;
