@@ -1,4 +1,4 @@
-use mlua::{AnyUserData, ExternalError, IntoLua, Lua, Table, UserData, Value};
+use mlua::{AnyUserData, ExternalError, Lua, Table, UserData, Value};
 use ratatui::widgets::Borders;
 
 use super::{RectRef, Renderable, Style};
@@ -26,17 +26,17 @@ impl Bar {
 
 		let bar = lua.create_table_from([
 			// Direction
-			("NONE", Borders::NONE.bits().into_lua(lua)?),
-			("TOP", Borders::TOP.bits().into_lua(lua)?),
-			("RIGHT", Borders::RIGHT.bits().into_lua(lua)?),
-			("BOTTOM", Borders::BOTTOM.bits().into_lua(lua)?),
-			("LEFT", Borders::LEFT.bits().into_lua(lua)?),
-			("ALL", Borders::ALL.bits().into_lua(lua)?),
+			("NONE", Borders::NONE.bits()),
+			("TOP", Borders::TOP.bits()),
+			("RIGHT", Borders::RIGHT.bits()),
+			("BOTTOM", Borders::BOTTOM.bits()),
+			("LEFT", Borders::LEFT.bits()),
+			("ALL", Borders::ALL.bits()),
 		])?;
 
 		bar.set_metatable(Some(lua.create_table_from([("__call", new)])?));
 
-		ui.set("Bar", bar)
+		ui.raw_set("Bar", bar)
 	}
 }
 
@@ -51,7 +51,7 @@ impl UserData for Bar {
 				let mut me = ud.borrow_mut::<Self>()?;
 				match value {
 					Value::Nil => me.style = None,
-					Value::Table(tb) => me.style = Some(Style::from(tb).0),
+					Value::Table(tb) => me.style = Some(Style::try_from(tb)?.0),
 					Value::UserData(ud) => me.style = Some(ud.borrow::<Style>()?.0),
 					_ => return Err("expected a Style or Table or nil".into_lua_err()),
 				}
