@@ -1,9 +1,7 @@
 mod fd;
 mod highlighter;
-mod lsar;
 mod rg;
 
 pub use fd::*;
 pub use highlighter::*;
-pub use lsar::*;
 pub use rg::*;
