@@ -1,12 +1,14 @@
 #![allow(clippy::module_inception)]
 
 mod entry;
+mod fetch;
 mod isolate;
 mod peek;
 mod preload;
 mod seek;
 
 pub use entry::*;
+pub use fetch::*;
 pub use isolate::*;
 pub use peek::*;
 pub use preload::*;
