@@ -26,11 +26,11 @@ impl AppProxy {
 	}
 
 	#[inline]
-	pub fn notify_warn(title: &str, content: &str) {
+	pub fn notify_warn(title: &str, content: impl ToString) {
 		emit!(Call(
 			Cmd::new("notify").with_any("option", NotifyOpt {
 				title:   title.to_owned(),
-				content: content.to_owned(),
+				content: content.to_string(),
 				level:   NotifyLevel::Warn,
 				timeout: Duration::from_secs(5),
 			}),
@@ -39,11 +39,11 @@ impl AppProxy {
 	}
 
 	#[inline]
-	pub fn notify_error(title: &str, content: &str) {
+	pub fn notify_error(title: &str, content: impl ToString) {
 		emit!(Call(
 			Cmd::new("notify").with_any("option", NotifyOpt {
 				title:   title.to_owned(),
-				content: content.to_owned(),
+				content: content.to_string(),
 				level:   NotifyLevel::Error,
 				timeout: Duration::from_secs(10),
 			}),
