@@ -1,7 +1,9 @@
 mod notify;
 mod open;
 mod process;
+mod search;
 
 pub use notify::*;
 pub use open::*;
 pub use process::*;
+pub use search::*;
