@@ -10,6 +10,7 @@ pub enum Layer {
 	Tasks,
 	Select,
 	Input,
+	Confirm,
 	Help,
 	Completion,
 	Which,
@@ -23,6 +24,7 @@ impl Display for Layer {
 			Self::Tasks => "tasks",
 			Self::Select => "select",
 			Self::Input => "input",
+			Self::Confirm => "confirm",
 			Self::Help => "help",
 			Self::Completion => "completion",
 			Self::Which => "which",
@@ -40,6 +42,7 @@ impl FromStr for Layer {
 			"tasks" => Self::Tasks,
 			"select" => Self::Select,
 			"input" => Self::Input,
+			"confirm" => Self::Confirm,
 			"help" => Self::Help,
 			"completion" => Self::Completion,
 			"which" => Self::Which,
